@@ -1,7 +1,7 @@
 """
 Type annotations for sagemaker-featurestore-runtime service type definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_sagemaker_featurestore_runtime/type_defs.html)
+[Open documentation](./type_defs.md)
 
 Usage::
 
@@ -22,11 +22,18 @@ else:
 
 __all__ = ("FeatureValueTypeDef", "GetRecordResponseTypeDef")
 
+FeatureValueTypeDef = TypedDict(
+    "FeatureValueTypeDef",
+    {
+        "FeatureName": str,
+        "ValueAsString": str,
+    },
+)
 
-class FeatureValueTypeDef(TypedDict):
-    FeatureName: str
-    ValueAsString: str
-
-
-class GetRecordResponseTypeDef(TypedDict, total=False):
-    Record: List["FeatureValueTypeDef"]
+GetRecordResponseTypeDef = TypedDict(
+    "GetRecordResponseTypeDef",
+    {
+        "Record": List["FeatureValueTypeDef"],
+    },
+    total=False,
+)
